@@ -1,10 +1,9 @@
 package urpm::lock;
 
-# $Id: lock.pm 261997 2009-10-15 17:44:35Z cfergeau $
 
 use strict;
 use urpm::msg;
-use urpm::util;
+use urpm::util 'cat_';
 
 #- avoid putting a require on Fcntl ':flock' (which is perl and not perl-base).
 my ($LOCK_SH, $LOCK_EX, $LOCK_NB, $LOCK_UN) = (1, 2, 4, 8);
@@ -19,18 +18,13 @@ urpm::lock - urpm/rpm DB locking related routines for urpmi
 
 =head1 DESCRIPTION
 
+=head1 CLASS FUNCTIONS
+
 =over
 
-=cut 
-
-
-################################################################################
-#- class functions
-
-
 =item rpm_db($urpm, $b_exclusive, %options)
 
-Lock urpmi DB.
+Lock rpm DB.
 
 Lock policy concerning chroot : lock rpm db in chroot
 
@@ -59,11 +53,29 @@ sub urpmi_db {
     urpm::lock->new($urpm, "$urpm->{statedir}/.LOCK", 'urpmi', $b_exclusive, %options);
 }
 
+=back
 
-################################################################################
-#- methods
+=head1 METHODS
+
+=over
+
+=item new($_class, $urpm, $file, $db_name, $b_exclusive, %options)
+
+Create a new lock.
+You don't want to use it directly. Either use urpmi_db() or rpm_db().
+
+Options:
+
+=over 4
+
+=item * nofatal
+
+=item * wait
+
+=back
+
+=cut
 
-# (options: nofatal, wait)
 sub new {
     my ($_class, $urpm, $file, $db_name, $b_exclusive, %options) = @_;
     
@@ -122,6 +134,14 @@ sub _lock {
     $lock->{exclusive} = $b_exclusive;
 }
 
+
+=item unlock($lock)
+
+Free a lock.
+
+=cut
+
+
 sub unlock {
     my ($lock) = @_;
     $lock->{fh} or warn "lock $lock->{db_name} already released\n", return;
@@ -138,7 +158,6 @@ sub DESTROY {
     my ($lock) = @_;
     unlock($lock) if $lock->{fh};
 }
-__END__
 
 =back
 
@@ -148,4 +167,6 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
+Copyright (C) 2011-2020 Mageia
+
 =cut
